@@ -1,7 +1,7 @@
 /*
  This file is part of MOST.
 
- Copyright (c) 1991, 1999, 2002, 2005 John E. Davis
+ Copyright (c) 1991, 1999, 2002, 2005, 2006, 2007 John E. Davis
 
  This program is free software; you can redistribute it and/or modify it
  under the terms of the GNU General Public License as published by the Free
@@ -35,6 +35,11 @@ void most_wide_width(void)
    SLtt_write_string ("\033[?3h");
 }
 
+void most_tt_set_color (int color)
+{
+   SLsmg_set_color (color);
+}
+
 void most_tt_bold_video (void)
 {
    SLsmg_set_color (MOST_BOLD_COLOR);
